@@ -56,8 +56,9 @@ enum
 static gboolean vino_prompt_display (VinoPrompt   *prompt,
 				     rfbClientPtr  rfb_client);
 
-static gpointer parent_class;
-static guint    prompt_signals [LAST_SIGNAL] = { 0 };
+static guint prompt_signals [LAST_SIGNAL] = { 0 };
+
+G_DEFINE_TYPE (VinoPrompt, vino_prompt, G_TYPE_OBJECT);
 
 static void
 vino_prompt_finalize (GObject *object)
@@ -76,8 +77,8 @@ vino_prompt_finalize (GObject *object)
   g_free (prompt->priv);
   prompt->priv = NULL;
 
-  if (G_OBJECT_CLASS (parent_class)->finalize)
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+  if (G_OBJECT_CLASS (vino_prompt_parent_class)->finalize)
+    G_OBJECT_CLASS (vino_prompt_parent_class)->finalize (object);
 }
 
 static void
@@ -119,7 +120,7 @@ vino_prompt_get_property (GObject    *object,
 }
 
 static void
-vino_prompt_instance_init (VinoPrompt *prompt)
+vino_prompt_init (VinoPrompt *prompt)
 {
   prompt->priv = g_new0 (VinoPromptPrivate, 1);
 }
@@ -130,8 +131,6 @@ vino_prompt_class_init (VinoPromptClass *klass)
   GObjectClass    *gobject_class = G_OBJECT_CLASS (klass);
   VinoPromptClass *prompt_class  = VINO_PROMPT_CLASS (klass);
   
-  parent_class = g_type_class_peek_parent (klass);
-  
   gobject_class->finalize     = vino_prompt_finalize;
   gobject_class->set_property = vino_prompt_set_property;
   gobject_class->get_property = vino_prompt_get_property;
@@ -161,34 +160,6 @@ vino_prompt_class_init (VinoPromptClass *klass)
   vino_init_stock_items ();
 }
 
-GType
-vino_prompt_get_type (void)
-{
-  static GType object_type = 0;
-
-  if (!object_type)
-    {
-      static const GTypeInfo object_info =
-	{
-	  sizeof (VinoPromptClass),
-	  (GBaseInitFunc) NULL,
-	  (GBaseFinalizeFunc) NULL,
-	  (GClassInitFunc) vino_prompt_class_init,
-	  NULL,           /* class_finalize */
-	  NULL,           /* class_data */
-	  sizeof (VinoPrompt),
-	  0,              /* n_preallocs */
-	  (GInstanceInitFunc) vino_prompt_instance_init,
-	};
-      
-      object_type = g_type_register_static (G_TYPE_OBJECT,
-                                            "VinoPrompt",
-                                            &object_info, 0);
-    }
-
-  return object_type;
-}
-
 VinoPrompt *
 vino_prompt_new (GdkScreen *screen)
 {
@@ -298,31 +269,14 @@ vino_prompt_setup_icons (VinoPrompt *prompt,
 {
 #define ICON_SIZE_STANDARD 48
 
-  GnomeIconTheme *icon_theme;
-  char           *icon_path;
-
   prompt->priv->sharing_icon = glade_xml_get_widget (xml, "sharing_icon");
   g_assert (prompt->priv->sharing_icon != NULL);
-  
-  icon_theme = gnome_icon_theme_new ();
-  gnome_icon_theme_set_allow_svg (icon_theme, TRUE);
 
-  icon_path = gnome_icon_theme_lookup_icon (icon_theme,
-					    "gnome-remote-desktop",
-					    ICON_SIZE_STANDARD,
-					    NULL, NULL);
-  if (icon_path)
-    {
-      gtk_window_set_icon_from_file (GTK_WINDOW (prompt->priv->dialog),
-				     icon_path,
-				     NULL);
-      gtk_image_set_from_file (GTK_IMAGE (prompt->priv->sharing_icon),
-			       icon_path);
-      g_free (icon_path);
-    }
+  gtk_window_set_icon_name (GTK_WINDOW (prompt->priv->dialog),
+			    "gnome-remote-desktop");
+  gtk_image_set_from_icon_name (GTK_IMAGE (prompt->priv->sharing_icon),
+				"gnome-remote-desktop", GTK_ICON_SIZE_DIALOG);
 
-  g_object_unref (icon_theme);
-  
 #undef ICON_SIZE_STANDARD
 }
 
@@ -360,7 +314,7 @@ vino_prompt_setup_dialog (VinoPrompt *prompt)
 
   help_button = glade_xml_get_widget (xml, "help_button");
   g_assert (help_button != NULL);
-  gtk_widget_set_sensitive (help_button, FALSE);
+  gtk_widget_hide (help_button);
 
   g_object_unref (xml);
 
@@ -396,7 +350,7 @@ vino_prompt_display (VinoPrompt   *prompt,
 
   prompt->priv->current_client = rfb_client;
 
-  gtk_widget_show_all (prompt->priv->dialog);
+  gtk_widget_show (prompt->priv->dialog);
 
   dprintf (PROMPT, "Prompting for client %p\n", rfb_client);
 
